==> vmaid-2.1.8.tar.gz: vmaid-2.1.8/w32loader/rasdlg.c <==
/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#include "rasdlg.h"


#ifdef W32LDR_HEADER
#include "pshpack4.h"
typedef struct _RASDIALDLG
{
  DWORD dwSize;
  HWND hwndOwner;
  DWORD dwFlags;
  LONG xDlg;
  LONG yDlg;
  DWORD dwSubEntry;
  DWORD dwError;
  ULONG_PTR reserved;
  ULONG_PTR reserved2;
} RASDIALDLG, *LPRASDIALDLG;
#include "poppack.h"
#endif /* W32LDR_HEADER */


/* DwTerminalDlg ordinal = 1, argument = 20 temporary */
static DWORD WINAPI DwTerminalDlg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* GetRasDialOutProtocols ordinal = 2, argument = 0 temporary */
static DWORD WINAPI GetRasDialOutProtocols (VOID)
{
  return 0;
}


/* RasAutodialDisableDlgA ordinal = 3, argument = 4 temporary */
static DWORD WINAPI RasAutodialDisableDlgA (DWORD dwArgv0)
{
  return 0;
}


/* RasAutodialQueryDlgA ordinal = 4, argument = 20 temporary */
static DWORD WINAPI RasAutodialQueryDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* RasDialDlgA ordinal = 5, argument = 16 temporary */
static DWORD WINAPI RasDialDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* RasDialDlgW ordinal = 6, argument = 16 temporary */
static DWORD WINAPI RasDialDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* RasEntryDlgA ordinal = 7, argument = 12 temporary */
static DWORD WINAPI RasEntryDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasEntryDlgW ordinal = 8, argument = 12 temporary */
static DWORD WINAPI RasEntryDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasMonitorDlgA ordinal = 9, argument = 8 temporary */
static DWORD WINAPI RasMonitorDlgA (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RasMonitorDlgW ordinal = 10, argument = 8 temporary */
static DWORD WINAPI RasMonitorDlgW (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RasPhonebookDlgA ordinal = 11, argument = 12 temporary */
static DWORD WINAPI RasPhonebookDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasPhonebookDlgW ordinal = 12, argument = 12 temporary */
static DWORD WINAPI RasPhonebookDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasSharedAccessSettingsDlg ordinal = 13, argument = 0 temporary */
static DWORD WINAPI RasSharedAccessSettingsDlg (VOID)
{
  return 0;
}


/* RasSrvAddPropPages ordinal = 14, argument = 20 temporary */
static DWORD WINAPI RasSrvAddPropPages (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* RasSrvAddWizPages ordinal = 15, argument = 12 temporary */
static DWORD WINAPI RasSrvAddWizPages (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasSrvAllowConnectionsConfig ordinal = 16, argument = 4 temporary */
static DWORD WINAPI RasSrvAllowConnectionsConfig (DWORD dwArgv0)
{
  return 0;
}


/* RasSrvCleanupService ordinal = 17, argument = 0 temporary */
static DWORD WINAPI RasSrvCleanupService (VOID)
{
  return 0;
}


/* RasSrvEnumConnections ordinal = 18, argument = 12 temporary */
static DWORD WINAPI RasSrvEnumConnections (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasSrvHangupConnection ordinal = 19, argument = 4 temporary */
static DWORD WINAPI RasSrvHangupConnection (DWORD dwArgv0)
{
  return 0;
}


/* RasSrvInitializeService ordinal = 20, argument = 0 temporary */
static DWORD WINAPI RasSrvInitializeService (VOID)
{
  return 0;
}


/* RasSrvIsConnectionConnected ordinal = 21, argument = 8 temporary */
static DWORD WINAPI RasSrvIsConnectionConnected (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RasSrvIsServiceRunning ordinal = 22, argument = 4 temporary */
static DWORD WINAPI RasSrvIsServiceRunning (DWORD dwArgv0)
{
  return 0;
}


/* RasSrvQueryShowIcon ordinal = 23, argument = 4 temporary */
static DWORD WINAPI RasSrvQueryShowIcon (DWORD dwArgv0)
{
  return 0;
}


/* RasUserEnableManualDial ordinal = 24, argument = 12 temporary */
static DWORD WINAPI RasUserEnableManualDial (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasUserGetManualDial ordinal = 25, argument = 12 temporary */
static DWORD WINAPI RasUserGetManualDial (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasUserPrefsDlg ordinal = 26, argument = 4 temporary */
static DWORD WINAPI RasUserPrefsDlg (DWORD dwArgv0)
{
  return 0;
}


/* RasWizCreateNewEntry ordinal = 27, argument = 20 temporary */
static DWORD WINAPI RasWizCreateNewEntry (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* RasWizGetSuggestedEntryName ordinal = 28, argument = 12 temporary */
static DWORD WINAPI RasWizGetSuggestedEntryName (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasWizIsEntryRenamable ordinal = 29, argument = 12 temporary */
static DWORD WINAPI RasWizIsEntryRenamable (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasWizQueryMaxPageCount ordinal = 30, argument = 4 temporary */
static DWORD WINAPI RasWizQueryMaxPageCount (DWORD dwArgv0)
{
  return 0;
}


/* RasWizSetEntryName ordinal = 31, argument = 12 temporary */
static DWORD WINAPI RasWizSetEntryName (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RouterEntryDlgA ordinal = 32, argument = 16 temporary */
static DWORD WINAPI RouterEntryDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* RouterEntryDlgW ordinal = 33, argument = 16 temporary */
static DWORD WINAPI RouterEntryDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


W32LdrExport rasdlg_exports[] = {
{FALSE,   1, "DwTerminalDlg",                DwTerminalDlg},
{FALSE,   2, "GetRasDialOutProtocols",       GetRasDialOutProtocols},
{FALSE,   3, "RasAutodialDisableDlgA",       RasAutodialDisableDlgA},
{FALSE,   4, "RasAutodialQueryDlgA",         RasAutodialQueryDlgA},
{FALSE,   5, "RasDialDlgA",                  RasDialDlgA},
{FALSE,   6, "RasDialDlgW",                  RasDialDlgW},
{FALSE,   7, "RasEntryDlgA",                 RasEntryDlgA},
{FALSE,   8, "RasEntryDlgW",                 RasEntryDlgW},
{FALSE,   9, "RasMonitorDlgA",               RasMonitorDlgA},
{FALSE,  10, "RasMonitorDlgW",               RasMonitorDlgW},
{FALSE,  11, "RasPhonebookDlgA",             RasPhonebookDlgA},
{FALSE,  12, "RasPhonebookDlgW",             RasPhonebookDlgW},
{FALSE,  13, "RasSharedAccessSettingsDlg",   RasSharedAccessSettingsDlg},
{FALSE,  14, "RasSrvAddPropPages",           RasSrvAddPropPages},
{FALSE,  15, "RasSrvAddWizPages",            RasSrvAddWizPages},
{FALSE,  16, "RasSrvAllowConnectionsConfig", RasSrvAllowConnectionsConfig},
{FALSE,  17, "RasSrvCleanupService",         RasSrvCleanupService},
{FALSE,  18, "RasSrvEnumConnections",        RasSrvEnumConnections},
{FALSE,  19, "RasSrvHangupConnection",       RasSrvHangupConnection},
{FALSE,  20, "RasSrvInitializeService",      RasSrvInitializeService},
{FALSE,  21, "RasSrvIsConnectionConnected",  RasSrvIsConnectionConnected},
{FALSE,  22, "RasSrvIsServiceRunning",       RasSrvIsServiceRunning},
{FALSE,  23, "RasSrvQueryShowIcon",          RasSrvQueryShowIcon},
{FALSE,  24, "RasUserEnableManualDial",      RasUserEnableManualDial},
{FALSE,  25, "RasUserGetManualDial",         RasUserGetManualDial},
{FALSE,  26, "RasUserPrefsDlg",              RasUserPrefsDlg},
{FALSE,  27, "RasWizCreateNewEntry",         RasWizCreateNewEntry},
{FALSE,  28, "RasWizGetSuggestedEntryName",  RasWizGetSuggestedEntryName},
{FALSE,  29, "RasWizIsEntryRenamable",       RasWizIsEntryRenamable},
{FALSE,  30, "RasWizQueryMaxPageCount",      RasWizQueryMaxPageCount},
{FALSE,  31, "RasWizSetEntryName",           RasWizSetEntryName},
{FALSE,  32, "RouterEntryDlgA",              RouterEntryDlgA},
{FALSE,  33, "RouterEntryDlgW",              RouterEntryDlgW},
{FALSE, 0, NULL, NULL}};

==> vmaid-2.2.2.tar.gz: vmaid-2.2.2/w32loader/rasdlg.c <==
/*
    w32loader
    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "rasdlg.h"


#ifdef W32LDR_HEADER
#include "pshpack4.h"
typedef struct _RASDIALDLG
{
  DWORD dwSize;
  HWND hwndOwner;
  DWORD dwFlags;
  LONG xDlg;
  LONG yDlg;
  DWORD dwSubEntry;
  DWORD dwError;
  ULONG_PTR reserved;
  ULONG_PTR reserved2;
} RASDIALDLG, *LPRASDIALDLG;
#include "poppack.h"
#endif /* W32LDR_HEADER */


/* DwTerminalDlg ordinal = 1, argument = 20 temporary */
static DWORD WINAPI DwTerminalDlg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* GetRasDialOutProtocols ordinal = 2, argument = 0 temporary */
static DWORD WINAPI GetRasDialOutProtocols (VOID)
{
  return 0;
}


/* RasAutodialDisableDlgA ordinal = 3, argument = 4 temporary */
static DWORD WINAPI RasAutodialDisableDlgA (DWORD dwArgv0)
{
  return 0;
}


/* RasAutodialQueryDlgA ordinal = 4, argument = 20 temporary */
static DWORD WINAPI RasAutodialQueryDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* RasDialDlgA ordinal = 5, argument = 16 temporary */
static DWORD WINAPI RasDialDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* RasDialDlgW ordinal = 6, argument = 16 temporary */
static DWORD WINAPI RasDialDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* RasEntryDlgA ordinal = 7, argument = 12 temporary */
static DWORD WINAPI RasEntryDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasEntryDlgW ordinal = 8, argument = 12 temporary */
static DWORD WINAPI RasEntryDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasMonitorDlgA ordinal = 9, argument = 8 temporary */
static DWORD WINAPI RasMonitorDlgA (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RasMonitorDlgW ordinal = 10, argument = 8 temporary */
static DWORD WINAPI RasMonitorDlgW (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RasPhonebookDlgA ordinal = 11, argument = 12 temporary */
static DWORD WINAPI RasPhonebookDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasPhonebookDlgW ordinal = 12, argument = 12 temporary */
static DWORD WINAPI RasPhonebookDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasSharedAccessSettingsDlg ordinal = 13, argument = 0 temporary */
static DWORD WINAPI RasSharedAccessSettingsDlg (VOID)
{
  return 0;
}


/* RasSrvAddPropPages ordinal = 14, argument = 20 temporary */
static DWORD WINAPI RasSrvAddPropPages (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* RasSrvAddWizPages ordinal = 15, argument = 12 temporary */
static DWORD WINAPI RasSrvAddWizPages (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasSrvAllowConnectionsConfig ordinal = 16, argument = 4 temporary */
static DWORD WINAPI RasSrvAllowConnectionsConfig (DWORD dwArgv0)
{
  return 0;
}


/* RasSrvCleanupService ordinal = 17, argument = 0 temporary */
static DWORD WINAPI RasSrvCleanupService (VOID)
{
  return 0;
}


/* RasSrvEnumConnections ordinal = 18, argument = 12 temporary */
static DWORD WINAPI RasSrvEnumConnections (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasSrvHangupConnection ordinal = 19, argument = 4 temporary */
static DWORD WINAPI RasSrvHangupConnection (DWORD dwArgv0)
{
  return 0;
}


/* RasSrvInitializeService ordinal = 20, argument = 0 temporary */
static DWORD WINAPI RasSrvInitializeService (VOID)
{
  return 0;
}


/* RasSrvIsConnectionConnected ordinal = 21, argument = 8 temporary */
static DWORD WINAPI RasSrvIsConnectionConnected (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RasSrvIsServiceRunning ordinal = 22, argument = 4 temporary */
static DWORD WINAPI RasSrvIsServiceRunning (DWORD dwArgv0)
{
  return 0;
}


/* RasSrvQueryShowIcon ordinal = 23, argument = 4 temporary */
static DWORD WINAPI RasSrvQueryShowIcon (DWORD dwArgv0)
{
  return 0;
}


/* RasUserEnableManualDial ordinal = 24, argument = 12 temporary */
static DWORD WINAPI RasUserEnableManualDial (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasUserGetManualDial ordinal = 25, argument = 12 temporary */
static DWORD WINAPI RasUserGetManualDial (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasUserPrefsDlg ordinal = 26, argument = 4 temporary */
static DWORD WINAPI RasUserPrefsDlg (DWORD dwArgv0)
{
  return 0;
}


/* RasWizCreateNewEntry ordinal = 27, argument = 20 temporary */
static DWORD WINAPI RasWizCreateNewEntry (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* RasWizGetSuggestedEntryName ordinal = 28, argument = 12 temporary */
static DWORD WINAPI RasWizGetSuggestedEntryName (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasWizIsEntryRenamable ordinal = 29, argument = 12 temporary */
static DWORD WINAPI RasWizIsEntryRenamable (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RasWizQueryMaxPageCount ordinal = 30, argument = 4 temporary */
static DWORD WINAPI RasWizQueryMaxPageCount (DWORD dwArgv0)
{
  return 0;
}


/* RasWizSetEntryName ordinal = 31, argument = 12 temporary */
static DWORD WINAPI RasWizSetEntryName (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* RouterEntryDlgA ordinal = 32, argument = 16 temporary */
static DWORD WINAPI RouterEntryDlgA (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* RouterEntryDlgW ordinal = 33, argument = 16 temporary */
static DWORD WINAPI RouterEntryDlgW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


W32LdrExport w32ldr_rasdlg_exports[] = {
{-1,   1, "DwTerminalDlg",                DwTerminalDlg},
{-1,   2, "GetRasDialOutProtocols",       GetRasDialOutProtocols},
{-1,   3, "RasAutodialDisableDlgA",       RasAutodialDisableDlgA},
{-1,   4, "RasAutodialQueryDlgA",         RasAutodialQueryDlgA},
{-1,   5, "RasDialDlgA",                  RasDialDlgA},
{-1,   6, "RasDialDlgW",                  RasDialDlgW},
{-1,   7, "RasEntryDlgA",                 RasEntryDlgA},
{-1,   8, "RasEntryDlgW",                 RasEntryDlgW},
{-1,   9, "RasMonitorDlgA",               RasMonitorDlgA},
{-1,  10, "RasMonitorDlgW",               RasMonitorDlgW},
{-1,  11, "RasPhonebookDlgA",             RasPhonebookDlgA},
{-1,  12, "RasPhonebookDlgW",             RasPhonebookDlgW},
{-1,  13, "RasSharedAccessSettingsDlg",   RasSharedAccessSettingsDlg},
{-1,  14, "RasSrvAddPropPages",           RasSrvAddPropPages},
{-1,  15, "RasSrvAddWizPages",            RasSrvAddWizPages},
{-1,  16, "RasSrvAllowConnectionsConfig", RasSrvAllowConnectionsConfig},
{-1,  17, "RasSrvCleanupService",         RasSrvCleanupService},
{-1,  18, "RasSrvEnumConnections",        RasSrvEnumConnections},
{-1,  19, "RasSrvHangupConnection",       RasSrvHangupConnection},
{-1,  20, "RasSrvInitializeService",      RasSrvInitializeService},
{-1,  21, "RasSrvIsConnectionConnected",  RasSrvIsConnectionConnected},
{-1,  22, "RasSrvIsServiceRunning",       RasSrvIsServiceRunning},
{-1,  23, "RasSrvQueryShowIcon",          RasSrvQueryShowIcon},
{-1,  24, "RasUserEnableManualDial",      RasUserEnableManualDial},
{-1,  25, "RasUserGetManualDial",         RasUserGetManualDial},
{-1,  26, "RasUserPrefsDlg",              RasUserPrefsDlg},
{-1,  27, "RasWizCreateNewEntry",         RasWizCreateNewEntry},
{-1,  28, "RasWizGetSuggestedEntryName",  RasWizGetSuggestedEntryName},
{-1,  29, "RasWizIsEntryRenamable",       RasWizIsEntryRenamable},
{-1,  30, "RasWizQueryMaxPageCount",      RasWizQueryMaxPageCount},
{-1,  31, "RasWizSetEntryName",           RasWizSetEntryName},
{-1,  32, "RouterEntryDlgA",              RouterEntryDlgA},
{-1,  33, "RouterEntryDlgW",              RouterEntryDlgW},
{-1,   0, NULL,                           NULL}};
